@@ -13,6 +13,14 @@ DRIVER = get_driver()
 GLOBAL_CONFIG = DRIVER.config
 LL_CONFIG = Config.parse_obj(GLOBAL_CONFIG)
 
+print("test i2ll config:")
+print(" i2ll_host: {}".format(LL_CONFIG.i2ll_host))
+print(" i2ll_port: {}".format(LL_CONFIG.i2ll_port))
+print(" i2ll_psk: {}".format(LL_CONFIG.i2ll_psk))
+print(" i2ll_timeout: {}".format(LL_CONFIG.i2ll_timeout))
+print(" i2ll_buffer_size: {}".format(LL_CONFIG.i2ll_clt_buffer))
+
+
 LL_CLT = I2LLClient(LL_CONFIG.i2ll_host, LL_CONFIG.i2ll_port, LL_CONFIG.i2ll_psk,
                     watchdog_timeout=LL_CONFIG.i2ll_timeout,
                     max_buffer_size=LL_CONFIG.i2ll_clt_buffer)
