@@ -14,7 +14,6 @@ config.i2ll_devices
 
 from pydantic import BaseSettings, BaseModel, Extra, validator
 from typing import List
-from i2llservice.client import DeviceClient
 
 
 class Devices(BaseModel, extra=Extra.ignore):
@@ -22,7 +21,6 @@ class Devices(BaseModel, extra=Extra.ignore):
     alias: List[str] = []
     root_topic: str
     permitted_group: List[int]
-    dev_clt: None = None
 
 
 class Config(BaseSettings, extra=Extra.ignore):
